@@ -2,4 +2,4 @@
 Provides Operators working on single tensors.
 """
 
-from .tensor import torch_one_hot, np_one_hot
+from .tensor import np_one_hot, torch_one_hot
